import numpy as np

def twoNumArray(x, y):
  arr = np.array([x, y])
  print(arr)

def threeNumArray(x, y, z):
  arr = np.array([x, y, z])
  print(arr)

def fourNumArray(a, b, c, d):
  arr = np.array([a, b, c, d])
  print(arr)

def fiveNumArray(a, b, c, d, e):
  arr = np.array([a, b, c, d, e])
  print(arr)


def findMonomialDegree(x):
  for character in x:
    if character.isdigit(0):
      print("Constant")
    if character.isdigit(1):
      print("Linear")
    if character.isdigit(2):
      print("Quadratic")
    if character.isdigit(3):
      print("Cubic")
    if character.isdigit(4):
      print("4th Degree")
    if character.isdigit(5):
      print("5th Degree")